@@ -16,6 +16,7 @@ from sqlalchemy import (
     DateTime,
     UniqueConstraint,
     ForeignKey,
+    UnicodeText,
 )
 from sqlalchemy.orm import sessionmaker, relationship, scoped_session, backref
 from sqlalchemy.ext.declarative import declarative_base
@@ -269,13 +270,15 @@ class Environment(Base):
 
     name = Column(Unicode(255), nullable=False)
 
-    current_build_id = Column(Integer, ForeignKey("build.id", use_alter=True))
+    current_build_id = Column(Integer, ForeignKey("build.id"))
     current_build = relationship(
         Build, foreign_keys=[current_build_id], post_update=True
     )
 
     deleted_on = Column(DateTime, default=None)
 
+    description = Column(UnicodeText, default=None)
+
 
 class CondaChannel(Base):
     __tablename__ = "conda_channel"
