@@ -135,6 +135,11 @@ def delete_build_artifact(conda_store, build_artifact):
         ):
             shutil.rmtree(conda_prefix)
             conda_store.db.delete(build_artifact)
+    elif build_artifact.artifact_type == schema.BuildArtifactType.CONTAINER_REGISTRY:
+        pass
+        # # container registry tag deletion is not generally implemented
+        # # the underlying library `python_docker` is already capable
+        # conda_store.container_registry.delete_image(build_artifact.key)
     elif build_artifact.artifact_type == schema.BuildArtifactType.LOCKFILE:
         pass
     else:
